Function syntax::parse::token::str_to_identUnstable
[-] [+]
[src]
pub fn str_to_ident(s: &str) -> Ident
Maps a string to an identifier with an empty syntax context.
pub fn str_to_ident(s: &str) -> Ident
Maps a string to an identifier with an empty syntax context.
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).